@@ -3,11 +3,11 @@ $TRANSLATIONS = array(
 "Documents" => "문서",
 "Can't create document" => "문서를 만들 수 없음",
 "You don't have permission to rename this document" => "이 문서의 이름을 변경할 권한이 없습니다",
-"Directory saved successfully." => "디렉터리를 저장하였습니다.",
-"An error occurred while changing directory." => "디렉터리를 변경하는 중 오류가 발생하였습니다.",
+"Directory saved successfully." => "디렉터리를 저장했습니다.",
+"An error occurred while changing directory." => "디렉터리를 변경하는 중 오류가 발생했습니다.",
 "Saved" => "저장됨",
 "Format filter server is down or misconfigured" => "포맷 필터 서버를 사용할 수 없거나 설정이 잘못되었습니다",
-"Conversion failed. Check log for details." => "변환이 실패하였습니다. 자세한 정보는 로그를 참조하십시오.",
+"Conversion failed. Check log for details." => "변환이 실패했습니다. 자세한 정보는 로그를 참조하십시오.",
 "Saving..." => "저장 중...",
 "Failed to load documents." => "문서를 불러올 수 없습니다.",
 "No documents were found. Upload or create a document to get started!" => "문서를 찾을 수 없습니다. 문서를 업로드하거나 새 문서를 만들 수 있습니다!",
@@ -89,7 +89,7 @@ $TRANSLATIONS = array(
 "Set expiration date" => "만료 날짜 설정",
 "Expiration" => "만료",
 "Expiration date" => "만료 날짜",
-"An error occured. Please try again" => "오류가 발생하였습니다. 다시 시도하십시오.",
+"An error occured. Please try again" => "오류가 발생했습니다. 다시 시도하십시오.",
 "Adding user..." => "사용자 추가 중...",
 "group" => "그룹",
 "remote" => "원격",
