@@ -77,14 +77,20 @@ OC.L10N.register(
     "Share with users, groups or remote users …" : "Споделено со корисници, групи или оддалечени корисници ...",
     "Share" : "Сподели",
     "Share link" : "Сподели ја врската",
+    "Link" : "Линк",
     "Password protect" : "Заштити со лозинка",
     "Password" : "Лозинка",
+    "Choose a password for the public link" : "Одбери лозинка за јавниот линк",
+    "Allow editing" : "Овозможи уредување",
     "Email link to person" : "Прати врска по е-пошта на личност",
     "Send" : "Прати",
     "Set expiration date" : "Постави рок на траење",
     "Expiration" : "Истекување",
     "Expiration date" : "Рок на траење",
+    "An error occured. Please try again" : "Се случи грешка. Обиди се повторно",
+    "Adding user..." : "Додади корисник...",
     "group" : "група",
+    "remote" : "далечински",
     "Resharing is not allowed" : "Повторно споделување не е дозволено",
     "Shared in {item} with {user}" : "Споделено во {item} со {user}",
     "Unshare" : "Не споделувај",
@@ -93,6 +99,7 @@ OC.L10N.register(
     "can edit" : "може да се измени",
     "access control" : "контрола на пристап",
     "create" : "креирај",
+    "change" : "промени",
     "delete" : "избриши",
     "Password protected" : "Заштитено со лозинка",
     "Error unsetting expiration date" : "Грешка при тргање на рокот на траење",
