@@ -3,7 +3,6 @@ $TRANSLATIONS = array(
 "Documents" => "Dokumenty",
 "Can't create document" => "Nie można utworzyć dokumentu",
 "You don't have permission to rename this document" => "Nie masz uprawnień do zmiany nazwy tego dokumentu",
-"File does not exist" => "Plik nie istnieje",
 "Directory saved successfully." => "Katalog zapisany poprawnie.",
 "An error occurred while changing directory." => "Pojawił się błąd podczas zmiany katalogu.",
 "Saved" => "Zapisano",
@@ -75,9 +74,7 @@ $TRANSLATIONS = array(
 "Shared with you and the group {group} by {owner}" => "Udostępnione tobie i grupie {group} przez {owner}",
 "Shared with you by {owner}" => "Udostępnione tobie przez {owner}",
 "Share with users or groups …" => "Współdziel z użytkownikami lub grupami",
-"Share with users, groups or remote users …" => "Współdziel z użytkownikami, grupami lub użytkownikami zdalnymi ...",
 "Share" => "Udostępnij",
-"Share with people on other ownClouds using the syntax username@example.com/owncloud" => "Współdziel z użytkownikami innych chmur ownCloud używając wzorca uzytkownik@example.com/owncloud",
 "Share link" => "Udostępnij link",
 "The public link will expire no later than {days} days after it is created" => "Link publiczny wygaśnie nie później niż po {days} dniach od utworzenia",
 "Link" => "Odnośnik",
@@ -90,7 +87,6 @@ $TRANSLATIONS = array(
 "Set expiration date" => "Ustaw datę wygaśnięcia",
 "Expiration" => "Wygaśnięcie",
 "Expiration date" => "Data wygaśnięcia",
-"An error occured. Please try again" => "Wystąpił błąd. Proszę spróbować ponownie.",
 "Adding user..." => "Dodawanie użytkownika...",
 "group" => "grupa",
 "remote" => "zdalny",
