@@ -4,7 +4,6 @@ OC.L10N.register(
     "Documents" : "Dokumenti",
     "Can't create document" : "Dokumenta ni mogoče ustvariti",
     "You don't have permission to rename this document" : "Ni ustreznih dovoljenj za preimenovanje tega dokumenta ...",
-    "File does not exist" : "Datoteka ne obstaja",
     "Directory saved successfully." : "Mapa je uspešno shranjena.",
     "An error occurred while changing directory." : "Med spreminjanjem mape je prišlo do napake.",
     "Saved" : "Shranjeno",
@@ -76,7 +75,7 @@ OC.L10N.register(
     "Shared with you and the group {group} by {owner}" : "V souporabi z vami in skupino {group}. Lastnik je {owner}.",
     "Shared with you by {owner}" : "V souporabi z vami. Lastnik je {owner}.",
     "Share with users or groups …" : "Souporaba z uporabniki ali skupinami ...",
-    "Share with users, groups or remote users …" : "Uporabniki, skupine ali zunanji uporabniki ...",
+    "Share with users, groups or remote users …" : "Souporaba z usporabniki, skupinami ali zunanjimi uporabniki ...",
     "Share" : "Souporaba",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Soupraba z ljudmi v drugih ownCloud oblakih v formatu uporabnik@domena.si/owncloud",
     "Share link" : "Povezava za souporabo",
