@@ -6,9 +6,14 @@ $TRANSLATIONS = array(
 "Directory saved successfully." => "資料夾已成功儲存.",
 "An error occurred while changing directory." => "變更資料夾時發生錯誤.",
 "Saved" => "已儲存",
+"Format filter server is down or misconfigured" => "格式過濾伺服器無法連接或配置錯誤",
+"Conversion failed. Check log for details." => "轉換失敗。詳細資訊請參考紀錄。",
 "Saving..." => "儲存中...",
 "Failed to load documents." => "載入文件失敗",
+"No documents were found. Upload or create a document to get started!" => "找不到文件。請開始上傳或建立一個文件！",
 "No connection to server. Trying to reconnect." => "未連接伺服器，嘗試連線中。",
+"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "從編輯模式離開當前頁面可能會導致資料遺失，建議改用'關閉'按鈕。",
+"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "讀取檔案失敗，請確認此檔案能夠以外部ODT編輯器開啟。同時此檔案可能已經關閉共享或是刪除。",
 "Save" => "儲存",
 "Loading documents..." => "讀取文件中...",
 "'.' is an invalid file name." => "'.' 是不合法的檔名",
@@ -39,6 +44,9 @@ $TRANSLATIONS = array(
 "Insert Image" => "插入圖片",
 "Invite Members" => "邀請會員",
 "Italic" => "斜體",
+"Justified" => "左右對齊",
+"Justify" => "對齊",
+"Left" => "靠左對齊",
 "Loading" => "載入中",
 "Members" => "會員",
 "New Name:" => "新名稱：",
@@ -48,7 +56,10 @@ $TRANSLATIONS = array(
 "Paragraph..." => "段落...",
 "Paragraph Styles" => "段落樣式",
 "Redo" => "重做",
+"Right" => "靠右對齊",
 "Size" => "大小",
+"Spacing" => "邊距",
+"Strikethrough" => "刪除線",
 "Style" => "樣式",
 "Text" => "文字",
 "Top" => "頂端",
@@ -62,12 +73,17 @@ $TRANSLATIONS = array(
 "Error while changing permissions" => "修改權限時發生錯誤",
 "Shared with you and the group {group} by {owner}" => "由 {owner} 分享給您和 {group}",
 "Shared with you by {owner}" => "{owner} 已經和您分享",
+"Share with users or groups …" => "與用戶或群組分享 ...",
+"Share with users, groups or remote users …" => "與用戶，群組或是遠端使用者分享 ...",
 "Share" => "分享",
+"Share with people on other ownClouds using the syntax username@example.com/owncloud" => "與其他在ownCloud上的人們分享，請使用此格式 username@example.com/owncloud",
 "Share link" => "分享連結",
 "The public link will expire no later than {days} days after it is created" => "這個公開連結會在 {days} 天內失效",
+"Link" => "連結",
 "Password protect" => "密碼保護",
 "Password" => "密碼",
 "Choose a password for the public link" => "為公開連結選一個密碼",
+"Allow editing" => "允許編輯",
 "Email link to person" => "將連結 email 給別人",
 "Send" => "寄出",
 "Set expiration date" => "指定到期日",
@@ -95,9 +111,13 @@ $TRANSLATIONS = array(
 "Warning" => "警告",
 "Edit" => "編輯",
 "guest" => "訪客",
+"MS Word support (requires openOffice/libreOffice)" => "微軟Word支援(需openOffice/libreOffice)",
 "Local" => "本地",
+"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "此伺服器已安裝openOffice/libreOffice，在config.php中的preview_libreoffice_path已指定執行程序的路徑。",
 "External" => "外部",
+"openOffice/libreOffice is installed on external server running a format filter server" => "openOffice/libreOffice已安裝正在執行格式過濾伺服器的外部伺服器上。",
 "Disabled" => "已停用",
+"No MS Word support" => "微軟Word不支援",
 "scheme://domain.tld[:port]" => "scheme://domain.tld[:port]",
 "Server URL" => "伺服器網址",
 "Apply and test" => "套用並測試",
@@ -107,6 +127,7 @@ $TRANSLATIONS = array(
 "Save new documents to" => "儲存新檔案至",
 "Wrong password. Please retry." => "密碼錯誤，請重新嘗試。",
 "Guest %s" => "訪客 %s",
+"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "此連結已失效或不存在，詳細資訊請聯繫此連結的分享者。",
 "Advanced feature-set" => "進階功能",
 "(Unstable)" => "（不穩定）"
 );
