@@ -109,7 +109,7 @@ class File {
 		$shareId  = $this->sharing['id'];
 		if (!$this->isPasswordProtected()
 			|| (\OC::$server->getSession()->exists('public_link_authenticated')
-				&& \OC::$server->getSession()->get('public_link_authenticated') === (string)$shareId
+				&& \OC::$server->getSession()->get('public_link_authenticated') === $shareId
 			)
 		){
 			return true;
@@ -118,7 +118,7 @@ class File {
 		// Check Password
 		$newHash = '';
 		if(\OC::$server->getHasher()->verify($password, $this->getPassword(), $newHash)) {
-			\OC::$server->getSession()->set('public_link_authenticated', (string)$shareId);
+			\OC::$server->getSession()->set('public_link_authenticated', $shareId);
 
 			/**
 			 * FIXME: Migrate old hashes to new hash format
@@ -171,6 +171,18 @@ class File {
 		$this->path = $this->ownerView->getPath($this->fileId);
 		$this->pathFiles = $this->ownerViewFiles->getPath($this->fileId);
 		
+		if (!$this->path || !$this->pathFiles) {
+			throw new \Exception($this->fileId . ' can not be resolved');
+		}
+		
+		if (!$this->ownerView->file_exists($this->path)) {
+			throw new \Exception($this->path . ' doesn\'t exist');
+		}
+		
+		if (!$this->ownerViewFiles->file_exists($this->pathFiles)) {
+			throw new \Exception($this->pathFiles . ' doesn\'t exist');
+		}
+		
 		if (!$this->ownerView->is_file($this->path)){
 			throw new \Exception('Object ' . $this->path . ' is not a file.');
 		}
